.. Equinox code documentation

Equinox Data Models
==============================
The following pages document the Equinox data models. Each data model is implemented in a separate file TABLE_NAME.py in the portfolio directory.

.. toctree::
   :maxdepth: 4

   Asset
   ProjectCompany
   Loan
   Contractor
   Operator
   Swap
   Stakeholders
   Sponsors
   Revenue


